@@ -560,6 +560,9 @@ grn_ctx_pull_child(grn_ctx *ctx)
   grn_ctx_use(child_ctx, grn_ctx_db(ctx));
   child_ctx->impl->parent = ctx;
   child_ctx->impl->command.version = ctx->impl->command.version;
+  child_ctx->impl->match_escalation_threshold =
+    ctx->impl->match_escalation_threshold;
+  child_ctx->impl->force_match_escalation = ctx->impl->force_match_escalation;
   child_ctx->impl->parallel.n_workers = ctx->impl->parallel.n_workers;
   CRITICAL_SECTION_LEAVE(ctx->impl->children.lock);
   return child_ctx;
@@ -645,19 +648,19 @@ grn_ctx_impl_clear_n_same_error_messagges(grn_ctx *ctx)
   ctx->impl->n_same_error_messages = 0;
 }
 
-grn_bool
+bool
 grn_ctx_impl_should_log(grn_ctx *ctx)
 {
   if (!ctx->impl) {
-    return GRN_TRUE;
+    return true;
   }
 
   if (strcmp(ctx->errbuf, ctx->impl->previous_errbuf) == 0) {
     ctx->impl->n_same_error_messages++;
-    return GRN_FALSE;
+    return false;
   }
 
-  return GRN_TRUE;
+  return true;
 }
 
 void
