@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2021-2022  Sutou Kouhei <kou@clear-code.com>
+  Copyright (C) 2021-2024  Sutou Kouhei <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -18,16 +18,20 @@
 #pragma once
 
 #include "grn_ctx.h"
+#include "grn_task_executor.hpp"
+
+GRN_API grn::TaskExecutor *
+grn_ctx_get_task_executor(grn_ctx *ctx);
 
 namespace grn {
   class ChildCtxReleaser {
   public:
-    ChildCtxReleaser(grn_ctx *ctx, grn_ctx *child_ctx) :
-      ctx_(ctx),
-      child_ctx_(child_ctx) {
-    };
+    ChildCtxReleaser(grn_ctx *ctx, grn_ctx *child_ctx)
+      : ctx_(ctx),
+        child_ctx_(child_ctx){};
 
-    ~ChildCtxReleaser() {
+    ~ChildCtxReleaser()
+    {
       if (child_ctx_) {
         grn_ctx_release_child(ctx_, child_ctx_);
       }
@@ -37,4 +41,4 @@ namespace grn {
     grn_ctx *ctx_;
     grn_ctx *child_ctx_;
   };
-}
+} // namespace grn
